%define module	dateutil

%bcond_with tests

Name:		python-%{module}
Summary:	Provides powerful extensions to the standard datetime module
Version:	2.8.2
Release:	%mkrel 5
License:	Python
Group:		Development/Python
URL:		https://pypi.python.org/pypi/python-dateutil/
Source0:	%{pypi_source}
BuildArch:	noarch
BuildRequires:	locales

%description
The dateutil module provides powerful extensions to the standard
datetime module available in Python. Features include:

* Computing of relative deltas (next month, next year, next Monday,
  last week of month, etc);
* Computing of relative deltas between two given date and/or datetime
  objects;
* Computing of dates based on very flexible recurrence rules, using a
  superset of the iCalendar specification. Parsing of RFC strings is
  supported as well;
* Generic parsing of dates in almost any string format;
* Timezone (tzinfo) implementations for tzfile(5) format files
  (/etc/localtime, /usr/share/zoneinfo, etc), TZ environment string
  (in all known formats), iCalendar format files, given ranges (with
  help from relative deltas), local machine timezone, fixed offset
  timezone, UTC timezone, and Windows registry-based time zones;
* Internal up-to-date world timezone information based on Olson's
  database;
* Computing of Easter Sunday dates for any given year, using Western,
  Orthodox or Julian algorithms;
* More than 400 test cases.

%package -n python3-%{module}
Group:		Development/Python
Summary:	Provides powerful extensions to the standard datetime module
BuildRequires:  pkgconfig(python3)
BuildRequires:  pyproject-rpm-macros
%if %{with tests}
BuildRequires:  python3dist(freezegun)
BuildRequires:  python3dist(hypothesis)
BuildRequires:  python3dist(pytest)
BuildRequires:  python3dist(six)
%endif
%{?python_provide:%python_provide python3-%{module}}

%description -n python3-%{module}
The dateutil module provides powerful extensions to the standard
datetime module available in Python3.

%prep
%autosetup -p1 -n python-dateutil-%{version}

iconv --from=ISO-8859-1 --to=UTF-8 NEWS > NEWS.new
mv NEWS.new NEWS

%generate_buildrequires
%pyproject_buildrequires

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{module}

%if %{with tests}
%check
export LC_ALL=C.UTF-8
%{__python3} -m pytest -W ignore::pytest.PytestUnknownMarkWarning
%endif

%files -n python3-%{module} -f %{pyproject_files}
%license LICENSE
%doc README.rst NEWS


%changelog
* Thu Dec 07 2023 wally <wally> 2.8.2-5.mga10
+ Revision: 2014793
- rebuild for py3.12
- BR pyproject-rpm-macros
- use pyproject rpm macros

* Thu Mar 24 2022 umeabot <umeabot> 2.8.2-4.mga9
+ Revision: 1824733
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tmb <tmb> 2.8.2-3.mga9
+ Revision: 1774223
- rebuild for python 3.10

* Sun Feb 06 2022 wally <wally> 2.8.2-2.mga9
+ Revision: 1771864
- rebuild for python3.10

* Sun Aug 08 2021 luigiwalser <luigiwalser> 2.8.2-1.mga9
+ Revision: 1740641
- 2.8.2

* Sun Mar 14 2021 wally <wally> 2.8.1-2.mga9
+ Revision: 1702594
- rebuild for python 3.9

* Tue Jun 09 2020 daviddavid <daviddavid> 2.8.1-1.mga8
+ Revision: 1591127
- new version: 2.8.1

* Sun Feb 16 2020 umeabot <umeabot> 2.8.0-5.mga8
+ Revision: 1530600
- Mageia 8 Mass Rebuild

* Wed Sep 04 2019 wally <wally> 2.8.0-4.mga8
+ Revision: 1437146
- rebuild with new python-rpm-macros

* Tue Sep 03 2019 wally <wally> 2.8.0-3.mga8
+ Revision: 1436791
- rebuild for python3.8
- disable tests for rebuild

* Fri Aug 30 2019 wally <wally> 2.8.0-2.mga8
+ Revision: 1435624
- drop python2 support

* Fri Apr 19 2019 wally <wally> 2.8.0-1.mga7
+ Revision: 1393373
- new version 2.8.0

* Mon Jan 07 2019 shlomif <shlomif> 2.7.5-2.mga7
+ Revision: 1350389
- Rebuild for python3 3.7

* Fri Nov 02 2018 kekepower <kekepower> 2.7.5-1.mga7
+ Revision: 1327747
- BR python[2,3]-setuptools_scm
- Update to version 2.7.5
- Renamed python-dateutil to python2-dateutil
- Use python_provide

* Thu Sep 20 2018 umeabot <umeabot> 2.4.2-6.mga7
+ Revision: 1288565
- Mageia 7 Mass Rebuild

* Sat Aug 05 2017 pterjan <pterjan> 2.4.2-5.mga7
+ Revision: 1135362
- Rebuild for python 3.6

* Thu Mar 17 2016 daviddavid <daviddavid> 2.4.2-4.mga6
+ Revision: 992382
- rediff unappliable patch0 and patch1 (since fixed autosetup)
- use new python macros

* Fri Feb 19 2016 umeabot <umeabot> 2.4.2-3.mga6
+ Revision: 970495
- Mageia 6 Mass Rebuild

* Wed Oct 07 2015 tv <tv> 2.4.2-2.mga6
+ Revision: 886989
- use new python macros
- use new python macros
- rebuild for python 3.5

* Fri Aug 14 2015 joequant <joequant> 2.4.2-1.mga6
+ Revision: 864733
- upgrade to 2.4.2

* Wed Oct 15 2014 umeabot <umeabot> 2.1-8.mga5
+ Revision: 739431
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.1-7.mga5
+ Revision: 728225
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.1-6.mga5
+ Revision: 687959
- Mageia 5 Mass Rebuild

* Sat May 31 2014 pterjan <pterjan> 2.1-5.mga5
+ Revision: 628543
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 2.1-4.mga4
+ Revision: 543223
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.1-3.mga4
+ Revision: 498354
- Rebuild to add different pythonegg provides for python 2 and 3

* Tue Jul 02 2013 philippem <philippem> 2.1-2.mga4
+ Revision: 449640
- add Python3

* Thu Jun 06 2013 colin <colin> 2.1-1.mga4
+ Revision: 438228
- Bump release to non-testing number.

* Thu Jun 06 2013 colin <colin> 2.1-0.1.mga4
+ Revision: 438222
- New version: 2.1

* Tue Jan 15 2013 umeabot <umeabot> 1.5-3.mga3
+ Revision: 388195
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Mar 27 2011 blino <blino> 1.5-2.mga1
+ Revision: 78054
- imported package python-dateutil


* Mon Nov 01 2010 Ahmad Samir <ahmadsamir@mandriva.org> 1.5-2mdv2011.0
+ Revision: 591649
- rebuild for python 2.7

* Sun Apr 04 2010 Guillaume Rousse <guillomovitch@mandriva.org> 1.5-1mdv2010.1
+ Revision: 531327
- update to new version 1.5

* Tue Sep 15 2009 Thierry Vignaud <tv@mandriva.org> 1.4.1-3mdv2010.0
+ Revision: 442092
- rebuild

* Fri Dec 26 2008 Adam Williamson <awilliamson@mandriva.org> 1.4.1-2mdv2009.1
+ Revision: 319472
- rebuild with python 2.6

  + Guillaume Rousse <guillomovitch@mandriva.org>
    - update to new version 1.4.1

* Thu Apr 17 2008 Adam Williamson <awilliamson@mandriva.org> 1.4-1mdv2009.0
+ Revision: 195461
- buildrequires python-setuptools
- new release 1.4

  + Thierry Vignaud <tv@mandriva.org>
    - fix no-buildroot-tag

* Fri Dec 14 2007 Jérôme Soyer <saispo@mandriva.org> 1.3-1mdv2008.1
+ Revision: 119766
- New release

* Tue Aug 21 2007 Adam Williamson <awilliamson@mandriva.org> 1.2-3mdv2008.0
+ Revision: 68660
- drop manual python-base dependency, there's an auto-generated one

* Tue Aug 21 2007 Adam Williamson <awilliamson@mandriva.org> 1.2-2mdv2008.0
+ Revision: 68590
- add some python requires
- noarch

* Tue Aug 21 2007 Adam Williamson <awilliamson@mandriva.org> 1.2-1mdv2008.0
+ Revision: 68575
- Import python-dateutil

